Description Usage Arguments Details Value
Seperate the extracted values of Lingo results by each dimmention.
1 | dimsep(eres.values)
|
eres.values |
values of Lingo results from
|
This function is used to seperate values of Lingo results into a list which can be easily used by R.
A list which includes "dim1", "dim2", ...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.