writeLingo: Write Lingo Data

Description Usage Arguments Details Value

Description

Write Lingo data into a text file.

Usage

1
  writeLingo(datalist, ldt = "lingo.txt")

Arguments

datalist

the data list for the Lingo data file.

ldt

the Lingo data file.

Details

This function is used to convert the data list in R into a data file which can be imported by Lingo.

Value

A Lingo data file contains all data which can be imported by Lingo code.


ctfysh/rlingo documentation built on May 14, 2019, 12:29 p.m.