Description Usage Arguments Details Value
Write Lingo data into a text file.
1 | writeLingo(datalist, ldt = "lingo.txt")
|
datalist |
the data list for the Lingo data file. |
ldt |
the Lingo data file. |
This function is used to convert the data list in R into a data file which can be imported by Lingo.
A Lingo data file contains all data which can be imported by Lingo code.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.